Exon

Struct Exon 

pub struct Exon { /* private fields */ }
Represents a genomic exon.

Exons can be coding and non-coding. Coding exons have CDS start and end position and a frame-offset.

use atglib::models::{Exon, Frame};

let start = 1;
let end = 10;
let non_coding_exon = Exon::new(start, end, None, None, Frame::None);

assert_eq!(non_coding_exon.is_coding(), false);

let coding_exon = Exon::new(start, end, Some(start), Some(end), Frame::Zero);

assert_eq!(coding_exon.is_coding(), true);

Implementations

Source

impl Exon

pub fn new( start: u32, end: u32, cds_start: Option<u32>, cds_end: Option<u32>, frame_offset: Frame, ) -> Exon

create a new Exon

use atglib::models::{Exon, Frame};

let start = 1;
let end = 10;
let non_coding_exon = Exon::new(start, end, None, None, Frame::None);

assert_eq!(non_coding_exon.is_coding(), false);

let coding_exon = Exon::new(start, end, Some(start), Some(end), Frame::Zero);

assert_eq!(coding_exon.is_coding(), true);
pub fn start(&self) -> u32

Genomic start (leftmost) position of the exon

pub fn start_mut(&mut self) -> &mut u32

modify the start

pub fn end(&self) -> u32

Genomic end (rightmost) position of the exon

pub fn end_mut(&mut self) -> &mut u32

modify the end

pub fn cds_start(&self) -> &Option<u32>

If the exon is coding, it contains the leftmost genomic coding nucleotide position

pub fn cds_start_mut(&mut self) -> &mut Option<u32>

modify the cds_start

pub fn cds_end(&self) -> &Option<u32>

If the exon is coding, it contains the rightmost genomic coding nucleotide position

pub fn cds_end_mut(&mut self) -> &mut Option<u32>

modify the cds_end

pub fn frame_offset(&self) -> &Frame

If the exon is coding, the Frame specifies the offset of the reading frame

pub fn frame_offset_mut(&mut self) -> &mut Frame

modify the frame offset

pub fn is_coding(&self) -> bool

Returns true if the exon contains a coding sequence (CDS)

Examples
use atglib::models::{Exon, Frame};

let start = 1;
let end = 2;
let mut a = Exon::new(start, end, None, None, Frame::None);
assert_eq!(a.is_coding(), false);
*a.cds_start_mut() = Some(1);
*a.cds_end_mut() = Some(2);
assert_eq!(a.is_coding(), true);
pub fn len(&self) -> u32

Returns the number of bp of the exon

pub fn is_empty(&self) -> bool

Only implemented to satisfy clippy… Exons cannot be empty.

pub fn coding_len(&self) -> u32

Returns the number of bp of the exon’s coding sequence Non-coding exons have 0 bp coding sequence

pub fn downstream_frame(&self) -> Option<Frame>

Returns the coding frame of the next coding exon

pub fn set_frame(&mut self, frame: Frame)